==> haskell-text-builder-0.6.5.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5.1
id: text-builder-0.6.5.1-69uKzUpl642Ifty1fGFdQ0
key: text-builder-0.6.5.1-69uKzUpl642Ifty1fGFdQ0
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 73543502c6b27dd84eb45266de65f70d
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-builder-0.6.5.1
hs-libraries: HStext-builder-0.6.5.1-69uKzUpl642Ifty1fGFdQ0
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10.1-4uaeG4IJCtgGIB2O8mddrT
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-builder-0.6.5.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-builder
version: 0.6.5.1
id: text-builder-0.6.5.1-9GbeYEfRv0cA1LW6GOTfF1
key: text-builder-0.6.5.1-9GbeYEfRv0cA1LW6GOTfF1
license: MIT
copyright: (c) 2017, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/text-builder
synopsis: An efficient strict text builder
category: Text
abi: 4decb53bc4a869005e72de099d8eff49
exposed: True
exposed-modules:
    Text.Builder
hidden-modules: Text.Builder.UTF16 Text.Builder.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-builder-0.6.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-builder-0.6.5.1
hs-libraries: HStext-builder-0.6.5.1-9GbeYEfRv0cA1LW6GOTfF1
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    bytestring-0.10.8.2 deferred-folds-0.9.10.1-HrbeXC3neHuF7Tkb7h8mQk
    text-1.2.3.1 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-text-builder/html/text-builder.haddock
haddock-html: /usr/share/doc/haskell-text-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
